@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.010-TRIAL-19-g36f4246
+package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.011-5-g487ceb7
 # ABSTRACT: Specify dynamic (user-side) prerequisites for your distribution
 # KEYWORDS: plugin distribution metadata MYMETA prerequisites Makefile.PL dynamic
 # vim: set ts=8 sts=4 sw=4 tw=78 et :
 
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 use Moose;
 with
@@ -287,7 +287,7 @@ Dist::Zilla::Plugin::DynamicPrereqs - Specify dynamic (user-side) prerequisites
 
 =head1 VERSION
 
-version 0.011
+version 0.012
 
 =head1 SYNOPSIS
 
